# PyAutoLens

Welcome to PyAutoLens! A project aiming to make strong gravitational lens modeling openly available to the astronomy community. The project is open-source and comes packaged as a set of easy-to-use Python modules. 

We're still working towards our first stable build, so if you check out of the code make sure you switch to the 'develop' branch to see where we're at ;).

PyAutoLens is based on the two methods below, but we've plans afoot to take it much further than what they achieved:

https://arxiv.org/abs/1412.7436

https://arxiv.org/abs/1708.07377

if You'd like to contribute, feel free to contact me!
